@@ -241,7 +241,7 @@
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="104"/>
         <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="390"/>
-        <source>Do you want to be asked for an output file everytime you choose to export?</source>
+        <source>Do you want to be asked for an output file every time you choose to export?</source>
         <translation>Desideri essere informato da un messaggio ogni volta che scegli di esportare?</translation>
     </message>
     <message>
@@ -1294,7 +1294,7 @@ Vuoi usarla? (Le vecchie preferenze saranno salvate in ~/.stopmotion/preferences
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="290"/>
-        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Numero di immagini&lt;/h4&gt; &lt;p&gt;Cambiando questo valore nella barra di selezione puoi specificare di quante immagini riavvolgere l&apos;animazione che dovrebbe essere mixata con la camere o con la modalità playback: quante immagini avviare .&lt;/p&gt; &lt;p&gt;Mixando le immagini precedenti nella camera puoi pià facilmente vedere come lo scatto successivo starà in relazione alle altre, e quindi produrre una animazione in stop motion più fluida!&lt;/p&gt;</translation>
     </message>
     <message>
