@@ -241,7 +241,7 @@
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="104"/>
         <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="390"/>
-        <source>Do you want to be asked for an output file everytime you choose to export?</source>
+        <source>Do you want to be asked for an output file every time you choose to export?</source>
         <translation>Запрашивать имя файла каждый раз, когда вы будете экспортировать?</translation>
     </message>
     <message>
@@ -1315,7 +1315,7 @@ values exists. Do you want to use this one? (Your old preferences
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="290"/>
-        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Количество изображений&lt;/h4&gt; &lt;p&gt;Изменяя значение этого ползунка, вы указываете, сколько предыдущихкадров будет наложено на изображение с камеры или, если вы находитесь в режиме воспроизведения,сколько кадров будет проиграно. &lt;/p&gt; &lt;p&gt;Накладывая предыдущие кадры на изображение с камеры, вы более чётко видите, как каждый последующий кадр соотносится с предыдущими, что позволяет вам создавать более плавную анимацию!&lt;/p&gt;</translation>
     </message>
     <message>
